# Installation des packages
install.packages( c('ggplot2','scales') )

# Activation des packages
library(ggplot2)
library(scales)

# Chargement des données
load("courses.RData")

###### Exemple introductif ######

ggplot(courses, aes(x=revenu, y=budget) ) + geom_point( )

ggplot( courses, aes(x=revenu, y=budget) ) + geom_point(color="blue",na.rm=TRUE) +
  geom_smooth(method="lm", se=FALSE, na.rm=TRUE, color="red") +
  coord_cartesian( xlim=c(1000,3500), ylim=c(0,600) ) +
  labs( x= "Revenu", y = "Budget", title ="Budget vs Revenu" )

###### Histogramme ######

ggplot(courses, aes(x=budget)) + geom_histogram()

ggplot(courses, aes(x=budget)) + 
  geom_histogram(binwidth=25, boundary=100, na.rm = TRUE, color="black", fill="pink")

ggplot(courses, aes(x=budget)) + 
  geom_histogram(binwidth=25, boundary=100, na.rm = TRUE, color="black", fill="pink")+
  coord_cartesian( xlim=c(0,600), ylim=c(0,10) ) +
  labs( x= "Budget", y = "Effetifs", title ="Histogramme de Budget" )

# Avec densité de la loi normale
ggplot(courses, aes(x=budget)) + 
  geom_histogram(aes(y = after_stat(density)), binwidth=25, boundary=0, color="black", 
               fill="green", na.rm = TRUE) +
  stat_function(fun = dnorm,
              args = list(mean = mean(courses$budget, na.rm=TRUE), 
                          sd = sd(courses$budget, na.rm=TRUE)), 
              color = "red", linewidth = 1)

# Histogrammes superposés
ggplot(subset(courses,!is.na(courses$sexe)), aes(x = budget, fill = sexe)) +
  geom_histogram(binwidth=50, position = "identity", alpha = 0.4, na.rm = TRUE)+
  labs( x= "Budget", y = "Effetifs", fill = "Sexe")


###### Boites à moustaches ######

# simple (horizontal)
ggplot(courses, aes(x=budget)) + geom_boxplot(color="black", fill="cyan4", na.rm=TRUE)

# simple (vertical)
ggplot(courses, aes(y=budget)) + geom_boxplot(color="black", fill="green4", na.rm=TRUE)

# simple (vertical) avec outliers
outlier_label <- function(outVar,outLabel) { # construit la liste des labels des outliers
  outlierLabel <- as.character(outLabel)
  outlierLabel[ outVar > quantile(outVar, 0.25, na.rm=TRUE)-1.5*IQR(outVar,na.rm=TRUE) &
                  outVar < quantile(outVar, 0.75, na.rm=TRUE)+1.5*IQR(outVar,na.rm=TRUE) ] <- ""
  return(outlierLabel)
}
ggplot(courses, aes(y=budget)) +
  geom_boxplot(color="black", fill="purple3", na.rm=TRUE) +
  geom_text(aes(y=budget,x=0, label = outlier_label(budget,lieu)), na.rm = TRUE, hjust = -0.3)

# plusieurs groupes
ggplot(subset(courses,!is.na(courses$lieu)), aes(x=budget, y=lieu)) +
  geom_boxplot(na.rm=TRUE, fill=hcl.colors(4))

# plusieurs variables
ggplot(courses) + 
  geom_boxplot(aes(y=budget, x="Budget"), na.rm=TRUE, fill="pink") + 
  geom_boxplot(aes(y=revenu, x="Revenu" ), na.rm=TRUE, fill="orange") +
  labs( y = "", x = "" )



###### Nuage de points ######

ggplot( courses, aes(x=revenu, y=budget) ) + geom_point(color="red",na.rm=TRUE)

ggplot( courses, aes(x=revenu, y=budget) ) + geom_point(color="blue",na.rm=TRUE) +
  coord_cartesian( xlim=c(1000,3500), ylim=c(0,600) ) +
  labs( x= "Revenu", y = "Budget", title ="Budget vs Revenu" )

# avec étiquette
ggplot(courses, aes(x=revenu, y=budget)) +
  geom_point(color="red", na.rm=TRUE ) +
  geom_text(label=courses$lieu, color="blue", na.rm=TRUE, size=3, hjust = -0.2)

# avec couleur selon variable qualitative
ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE)

# suppression des données manquantes
ggplot(subset(courses, !is.na(lieu)), aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE)+
  labs(x="Revenu", y="Budget", color="Lieu")

# Couleurs personalisées
ggplot(subset(courses, !is.na(lieu)), aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE)+
  labs(x="Revenu", y="Budget", color="Lieu") + 
  scale_colour_manual(values = c("red", "blue", "green","orange"))

# Palette de couleurs
ggplot(subset(courses, !is.na(lieu)), aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE)+
  labs(x="Revenu", y="Budget", color="Lieu") + 
  scale_colour_brewer(palette = "Reds")

# Lignes de référence
ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE) +
  geom_hline(yintercept=mean(courses$budget, na.rm=TRUE), color="red") +
  geom_vline(xintercept=mean(courses$revenu, na.rm=TRUE), color="blue") +
  geom_abline(intercept = 0, slope = 0.1, color="purple")




###### Diagramme en bâtons ######

## Une seule variable

ggplot(courses, aes(x = lieu )) +
  geom_bar(fill="orange")

# identique à
ggplot(courses, aes(x = lieu, y=stat(count) )) +
  geom_bar(fill="orange2")

# Suppression des NA's
ggplot(subset(courses, !is.na(courses$lieu)), aes(x = lieu )) +
  geom_bar(fill="orange")

# Tri decroissant
ggplot(courses, aes(x = reorder(lieu,lieu, length, decreasing = TRUE ) )) +
  geom_bar(fill=hcl.colors(5)) + labs(x="Lieu", y="Effectifs")

# En pourcentages
ggplot(subset(courses, !is.na(courses$lieu)), 
       aes(x = reorder(lieu, lieu, length, decreasing = TRUE), y = after_stat(prop), group=1)) +
  geom_bar(fill=hcl.colors(4)) + scale_y_continuous(labels=percent_format()) +
  labs(x="Lieu", y="Pourcentages")



## Deux variables variables

ggplot(courses, aes(x = lieu , fill=sexe)) +
  geom_bar() +
  labs(fill="Sexe", x="Lieu", y="Effectif")

# Suppression des données manquantes
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar() +
  labs(fill="Sexe", x="Lieu", y="Effectif") 

# couleurs personalisées
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar() +
  scale_fill_manual(values=c("pink", "lightblue")) +
  labs(fill="Sexe", x="Lieu", y="Effectif") 

# Couleur auto
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar() +
  scale_fill_brewer(palette = "Paired") +
  labs(fill="Sexe", x="Lieu", y="Effectif") 

# Bâtons juxtaposés
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar(position = "dodge") +
  scale_fill_brewer(palette = "Accent") +
  labs(fill="Sexe", x="Lieu", y="Effectif") 

## Bâtons empilés à 100 %
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar(position = "fill") +
  scale_y_continuous(labels=percent_format()) +
  scale_fill_brewer(palette = "Pastel2") +
  labs(fill="Sexe", x="Lieu", y="Pourcentage") 


## Une variable quantitative (moyenne)

# Première méthode
ggplot(subset(courses,!is.na(courses$budget) & !is.na(courses$lieu)), aes(x=lieu, y=budget)) +
  geom_bar(stat = "summary", fun="mean")

# Seconde méthode
ggplot(subset(courses,!is.na(courses$budget) & !is.na(courses$lieu)), aes(x=lieu, y=budget)) +
  stat_summary(fun = "mean", geom = "bar") 

# Tri croissant et décroissant
ggplot(subset(courses,!is.na(courses$budget) & !is.na(courses$lieu)), aes(x=reorder(lieu,budget,mean), y=budget)) +
  stat_summary(fun = "mean", geom = "bar") +
  xlab("Lieu")

# Couleurs personalisées
ggplot(subset(courses,!is.na(courses$budget) & !is.na(courses$lieu)), aes(x=reorder(lieu,budget,mean, decreasing=TRUE), y=budget)) +
  stat_summary(fun = "mean", geom = "bar", fill=hcl.colors(4)) +
  labs(x = "Lieu", y = "Budget moyen")



###### Diagramme en secteurs ######

ggplot(courses, aes( x="", fill=lieu )) +
  geom_bar(width=1) +
  coord_polar("y") + labs(fill="Lieu")

ggplot(subset(courses,!is.na(courses$lieu)), aes(   x="", fill=lieu  )) +
  geom_bar() +
  coord_polar("y")

# sans données manquantes
ggplot(subset(courses,!is.na(courses$lieu)), aes(   x="", fill=lieu  )) +
  geom_bar(color="black") +
  coord_polar("y") + theme_void()

# Avec étiquette dans les secteurs
ggplot(subset(courses,!is.na(courses$lieu)), aes( x="", fill=lieu)) +
  geom_bar(color="black") +
  geom_text(aes(label = lieu , y = after_stat(count)),
            stat = "count", color="white", fontface = "bold",
            position = position_stack(vjust = 0.5)) +
  coord_polar("y") + theme_void() + theme(legend.position = "none")

# Avec effectifs dans les secteurs
ggplot(subset(courses,!is.na(courses$lieu)), aes(   x="", fill=lieu)) +
  geom_bar(color="black") +
  geom_text(aes(label = after_stat(count) , y = after_stat(count)),
            stat = "count", color="white", fontface = "bold",
            position = position_stack(vjust = 0.5)) +
  coord_polar("y") + theme_void()

# Avec % dans les secteurs
ggplot(subset(courses,!is.na(courses$lieu)), aes(   x="", fill=lieu)) +
  geom_bar(color="black") +
  geom_text(aes(label = paste(round(100*after_stat(count/ sum(count)),2),"%") , y = after_stat(count)),
            stat = "count", color="white", fontface = "bold",
            position = position_stack(vjust = 0.5)) +
  coord_polar("y") + theme_void()



###### Série de graphique ######

# histogrammes par groupe (1 variable)
ggplot(subset(courses, !is.na(courses$lieu)), aes(x=budget)) + 
  geom_histogram(binwidth=20, color="black", fill="lightblue2", boundary=1) +
  labs(x= "Budget", y = "Effectifs") +
  facet_wrap(vars(lieu), nrow = 3) 

# histogrammes par groupe (2 variables)
ggplot(subset(courses,!is.na(courses$lieu)), aes(x=budget)) + 
  geom_histogram(binwidth=20, color="black", fill="lightblue2", boundary=0) +
  facet_grid(cols=vars(frequence), rows=vars(lieu)) + 
  labs( x= "Budget", y = "Effetifs")

# barplot par groupe (2 variables)
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x=lieu)) +
      geom_bar() + theme(axis.text.x = element_text(size = 6)) +
  facet_grid(cols=vars(frequence), rows=vars(sexe))



###### Formes ######

ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE, shape="square")

ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE, shape="diamond open", size=5)

ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE, shape="triangle filled", size=3, color="blue", fill="red")



###### Couleurs ######

ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE, shape="square");
ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE, shape="diamond open", size=5);
ggplot(courses, aes(x=revenu, y=budget)) + geom_point(na.rm=TRUE, shape="triangle filled", size=3, color="blue", fill="red")
  
ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE) + 
  scale_colour_manual(values=c('blue','red','green','orange'))

# Brewer Palettes
ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar(position = "fill") + scale_y_continuous(labels=percent_format()) +
  scale_fill_brewer(palette = "Accent") + labs(fill="Sexe", x="Lieu", y="Pourcentage") 

ggplot(subset(courses,!is.na(courses$lieu) & !is.na(courses$sexe)), aes(x = lieu , fill=sexe)) +
  geom_bar(position = "fill") + scale_fill_brewer(palette = "Accent") 

library(RColorBrewer)
display.brewer.all()

# Viridis Palette
ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point() + scale_colour_viridis_d()
ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point() + 
  scale_colour_viridis_d(option="plasma")

# Themes

theme_get() # current theme settings

ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE) 

ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE) + 
  theme_light(base_size=9, base_family = "Verdana")

ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE) + 
  theme_classic(base_size=9, base_family = "serif") +
  theme(legend.position = "bottom", axis.text = element_text(colour = "blue"))

theme_set(theme_dark(base_size = 13)) # nouveau theme par defaut

ggplot(courses, aes(x=revenu, y=budget, color=lieu)) + geom_point(na.rm=TRUE) 


