# Installation des packages (à exécuter une seule fois)
install.packages(c('DescTools','psych','readxl'))

# Importation et préparation des données (à faire une seule fois)
library(readxl)
courses <- read_excel("courses.xlsx")
courses$sexe <- factor(courses$sexe)
courses$lieu <- factor(courses$lieu, level=c(1,2,3,4), labels=c('Hyper', 'Super', 'Proximité', 'Specialisé'))
courses$frequence <- ordered(courses$frequence, level=c(1,2,3,4), labels=c('Mensuel','Bimensuel','Hebdomadaire','Plus souvent'))
courses$sitfam <- factor(courses$sitfam, level=c(1,2,3,4,5), labels=c('Célibataire','Pacsé','Marié','Divorcé','Veuf'))

# Vérification des données
str(courses)
head(courses)

# Enregistrement des données (pour usage externe)
save(courses, file = "courses.RData")


# Chargement des packages (à executer à chaque session)
library(DescTools); library(psych); 
options(scipen=999)

attach(courses)


# STATISTIQUES UNIVARIÉES

## variables quantitatives

mean(revenu);mean(revenu, na.rm=TRUE)
sd(revenu, na.rm=TRUE)
summary(revenu)
describe(revenu, fast=TRUE)
describe( data.frame(age, revenu, budget), fast= TRUE )
describe( courses[c('age', 'revenu', 'budget')], fast= TRUE)
hist(budget);boxplot(budget)

hist(budget, col='lightblue', xlim=c(0,500), ylim=c(0,25), xlab='Budget', ylab='Effectif', main='Histogramme', breaks=6)


# Histogramme avec classe de largeur 50 et axe gradué de même
hist(budget, col='lightblue', xlim=c(0,600), ylim=c(0,25), xlab='Budget', ylab='Effectif', 
  	main='Histogramme', breaks=seq(0,600,50),  axes=FALSE)
axis(1, at=seq(0,600, 50), cex.axis=0.8) # Axe horizontal
axis(2, cex.axis=0.8) # Axe vertical

boxplot(budget, col='orange', xlab='Budget', horizontal=TRUE, main='Boite à moustache')

## Variables qualitatives

table(lieu)
prop.table(table(lieu))
Freq(lieu)
Freq(lieu, ord='desc')
pie( table(lieu) )
barplot( table(lieu) )

barplot(
  sort( prop.table( table(lieu) )*100, decreasing=TRUE), ylab='Pourcentages', ylim=c(0,50), col=c('blue','red','green','orange'),
  cex.names=0.8, cex.lab=0.8
)

# Version horizontale

barplot(
  sort( prop.table( table(lieu) )*100, decreasing=TRUE), xlab='Pourcentages', xlim=c(0,50), col=c('blue','red','green','orange'),
  cex.names=0.8, cex.lab=0.8, cex.axis=0.8, horiz=TRUE, las=2
)


## Question à réponses multiples (Multiples Response Variable)

source('MultipleResponse.R')
myres<-multipleResponse(courses, c('supermarche','hypermarche','proximite','specialise'),
                 order='decreasing',plot='percentage',ylim=c(0,70), main="Lieux d'achats",ylab="% d'observations",
                 names=c('Supermarché', 'Hypermarché', 'Proximité','Spécialisé'), col='orange3', cex.names=0.8)


myres[order(myres$Frequency),]->tmp

tmp

#mtcars[order(mpg),]

library(ggplot2)

ggplot(tmp, aes(reorder(Option, -Frequency), Frequency )) + geom_col(fill="orange")

ggplot(tmp, aes(Option, Frequency )) + geom_bar(stat = "identity")

# STATISTIQUES BIVARIÉES

## variables quantitatives

cov(revenu,budget,use="complete.obs")
cor(revenu,budget,use="complete.obs")
cor(data.frame(age,revenu,budget),use="pairwise.complete.obs")

plot(revenu,budget, xlab='Revenu',ylab='Budget')
text(revenu,budget,num,pos=4)
abline(v=mean(revenu, na.rm=TRUE) )
abline(h=mean(budget, na.rm=TRUE) )

plot(age,revenu,xlab='Age',ylab='Revenu', pch = c(16,17)[sexe])
legend('topleft', legend = levels(sexe), pch = c(16,17))

plot(age,revenu,xlab='Age',ylab='Revenu', pch= 19, col = c('red','blue')[sexe] )
legend('topleft', legend = levels(sexe), cex=0.8, pch=19, col=c('red','blue') )

## Variables qualitatives

table(lieu,frequence)
round( prop.table(table(lieu,frequence))*100, 2 )

round( prop.table(table(lieu,frequence), margin=1)*100, 2 )

PercTable(lieu,frequence, freq=F, rfrq="010", margins=2, digits=2)


barplot(
  table(frequence,lieu), 
  col=c('skyblue','steelblue1','steelblue3','steelblue4'),
  ylim=c(0,25), cex.names=0.8
)
legend(
    "topright",legend = levels(frequence), 
    col=c('skyblue','steelblue1','steelblue3','steelblue4'), pch = 16, cex=0.7
)

barplot(
  table(frequence,lieu), 
  col=c('skyblue','steelblue1','steelblue3','steelblue4'),
  ylim=c(0,7), cex.names=0.8, beside=TRUE
)
legend(
  "topright",legend = levels(frequence), 
  col=c('skyblue','steelblue1','steelblue3','steelblue4'), pch = 16, cex=0.7
)

barplot(
  prop.table( table(frequence,lieu),margin=2 )*100, 
  col=c('skyblue','steelblue1','steelblue3','steelblue4'),
  xlim=c(0,6))
legend(
  "topright",legend = levels(frequence), 
  col=c('skyblue','steelblue1','steelblue3','steelblue4'), pch = 16, cex=0.7
)


Phi(lieu,frequence)
CramerV(lieu,frequence)
chisq.test(lieu,frequence)

## Variable quantitative / Variable qualitative

tapply(budget, lieu, mean, na.rm=TRUE)
describeBy(budget, lieu, mat=TRUE, fast=TRUE)
boxplot(budget ~ lieu, col='lightgreen', cex.axis=0.9)
points(tapply(budget, lieu, mean), col="red", pch=20)

barplot( tapply(budget, lieu, mean, na.rm=TRUE) , ylab="Budget")

library(lattice)
histogram(~ budget | lieu, col='violet', main='Histogramme', xlab='Budget', ylab='Effectif', 
          layout=c(1,5))

hist(budget, col='blue', main="Histogram")

# Intervalles de confiance

t.test(budget, conf.level = 0.90)$conf.int[1:2]
MeanCI(budget, conf.level = 0.90, na.rm=TRUE)
MeanCI(budget, conf.level = 0.90, sd=9, na.rm=TRUE)

VarCI(budget, conf.level = 0.95, na.rm=TRUE)

table(supermarche)
prop.test(22,24+22, conf.level = 0.95)$conf.int[1:2]
binom.test(22,24+22, conf.level = 0.95)$conf.int[1:2]
BinomCI(24,24+22,conf.level=0.95, method="wilson")
BinomCI(24,24+22,conf.level=0.95, method="wald")

# Tests

## Tests sur un échantillon unique

ZTest(budget, mu=200, sd_pop=90, alternative = 'two.sided')
t.test(budget, mu=200, alternative = 'two.sided')
VarTest(budget, sigma.squared=90^2, alternative = 'greater')

prop.test(22,24+22, p=0.45, alternative = 'greater')
binom.test(22,24+22, p=0.45, alternative = 'greater')

## Tests sur deux échantillons indépendants

var.test(revenu ~ sexe, alternative='two.sided')
LeveneTest(revenu ~ sexe, alternative='two.sided', center=mean)

t.test(revenu ~ sexe, alternative='two.sided', var.equal=TRUE)

table(proximite,sexe)
prop.test(c(2,10),c(2+22,10+5))

## Tests sur deux échantillons appariés

t.test(revenu, budget, paired=TRUE, alternative='two.sided')

## Tests de normalité

shapiro.test(budget)
JarqueBeraTest(budget, na.rm=TRUE)
LillieTest(budget)
CramerVonMisesTest(budget)
ShapiroFranciaTest(budget)

hist(budget, freq = F, ylim = c(0, 0.008), col='seagreen3', xlab='Budget', main="Histogramme de budget")
curve(dnorm(x, mean(budget,na.rm=TRUE), sd(budget,na.rm=TRUE)), add=TRUE, col='red')

qqnorm(revenu)
qqline(revenu,col='red')

# Analyse de la variance

aovbudget <- aov(budget ~ lieu)
summary(aovbudget)
TukeyHSD(aovbudget)
bartlett.test(budget ~ lieu)
LeveneTest(budget ~ lieu, center='mean',alternative='two.sided')

# Régression linéaire

lm( budget ~ revenu) -> reg
summary(reg)

plot(revenu, budget, xlab='Revenu', ylab='Budget')
abline(reg, col='red')

shapiro.test(resid(reg))

plot(reg)

# Manipulation des données

courses[,2]
courses[,'age']
courses[,c('age','revenu')]
courses[7,]
courses[7:9,]
courses[7,'revenu']
revenu[7]

revenu[sexe=='F']
revenu[sexe=='F' & (revenu < 1500 | revenu > 2000)]

subset(courses, sexe=='F' & revenu > 2000) -> aSubset
head(aSubset)

revenuclass <- cut(revenu, c(0,1500,2000,2500,3000,3500), dig.lab = 5)
table(revenuclass)

# Couleurs !

hist(age, col='lightblue')
barplot(table(lieu),col=c('lightblue','pink','seagreen3','gray'))

pie(rep(1,12),col=rainbow(12))
pie(rep(1,8),col=hcl.colors(8))

# Probabilités et échantillons

pnorm(1.96, mean=0, sd=1) # P(N(0,1) <= 1.96)
qnorm(0.95, mean=0, sd=1) # z_0.95
pt(2.1, df=50) # P(St(50) <= 2.1)
qchisq(0.99, df=12) # quantile d'ordre 99% du khi-deux(12)
pf(9.3, df1=10, df2=15) # P(F(10,12) <= 9.3)
pbinom(5, size=20, prob=0.25) # P(B(20,0.25) < 5)

set.seed(12345678)
rnorm(5, mean=1, sd=2)

# Calcul matriciel

A <- matrix(c(1,2,3,4), ncol=2, nrow=2);A
B <- matrix(c(1,2,3,4,5,6), ncol=3, byrow=TRUE);B
C <- diag(c(-2,3));C

2*B
A+C
t(B)

A %*% B
det(A)
solve(A)

E <- matrix(c(2,1,1,2),ncol=2);E
eigen(E)

eigen(E)$vectors * sqrt(2)

# Likert Plot
install.packages("likert")
library(likert)

